.. _core-operators-api:

Base operator
=============

.. automodule:: tidyms2.core.operators.base
   :members:
        BaseOperator,
   :show-inheritance:


Sample operators
================

.. automodule:: tidyms2.core.operators.sample
   :members:
          SampleOperator,
          RoiExtractor,
          RoiTransformer,
          FeatureExtractor,
          FeatureTransformer,
   :show-inheritance:

Assay operators
===============

.. automodule:: tidyms2.core.operators.assay
   :members:
          AnnotationPatcher,
          DescriptorPatcher,
          MissingImputer,
   :show-inheritance:

Matrix operators
================

.. automodule:: tidyms2.core.operators.matrix
   :members:
          MatrixOperator,
          MatrixTransformer,
          ColumnTransformer,
          RowTransformer,
          ColumnFilter,
          RowFilter,
   :show-inheritance: